changeset 7879:e0f3cfb55df7

(mouse-avoidance-threshold): Renamed from ...threshhold.
author Richard M. Stallman <rms@gnu.org>
date Tue, 14 Jun 1994 00:10:56 +0000
parents 546334ab3974
children 3dd8448eee15
files lisp/avoid.el
diffstat 1 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/avoid.el	Mon Jun 13 23:56:48 1994 +0000
+++ b/lisp/avoid.el	Tue Jun 14 00:10:56 1994 +0000
@@ -83,7 +83,7 @@
 (defvar mouse-avoidance-nudge-dist 15
   "*Average distance that mouse will be moved when approached by cursor.
 Only applies in mouse-avoidance-mode `jump' and its derivatives.
-For best results make this larger than `mouse-avoidance-threshhold'.")
+For best results make this larger than `mouse-avoidance-threshold'.")
 
 (defvar mouse-avoidance-nudge-var 10
   "*Variability of `mouse-avoidance-nudge-dist' (which see).")
@@ -91,7 +91,7 @@
 (defvar mouse-avoidance-animation-delay .01
   "Delay between animation steps, in seconds.")
 
-(defvar mouse-avoidance-threshhold 5
+(defvar mouse-avoidance-threshold 5
   "*Mouse-pointer's flight distance.
 If the cursor gets closer than this, the mouse pointer will move away.
 Only applies in mouse-avoidance-modes `animate' and `jump'.")
@@ -143,14 +143,14 @@
       
 (defun mouse-avoidance-too-close-p (mouse)
   ;;  Return t if mouse pointer and point cursor are too close.
   ;; Acceptable distance is defined by mouse-avoidance-threshhold.
   (let ((point (mouse-avoidance-point-position)))
     (and (eq (car mouse) (car point))
 	 (car (cdr mouse))
 	 (< (abs (- (car (cdr mouse)) (car (cdr point))))
-	    mouse-avoidance-threshhold)
+	    mouse-avoidance-threshold)
 	 (< (abs (- (cdr (cdr mouse)) (cdr (cdr point))))
-	    mouse-avoidance-threshhold))))
+	    mouse-avoidance-threshold))))
 
 (defun mouse-avoidance-banish-destination ()
   "The position to which mouse-avoidance-mode `banish' moves the mouse.
@@ -311,7 +311,7 @@
 
 Whenever the mouse is moved, the frame is also raised.
 
-\(see `mouse-avoidance-threshhold' for definition of \"too close\",
+\(see `mouse-avoidance-threshold' for definition of \"too close\",
 and `mouse-avoidance-nudge-dist' and `mouse-avoidance-nudge-var' for
 definition of \"random distance\".)"
   (interactive
@@ -143,14 +143,14 @@
 (defun mouse-avoidance-too-close-p (mouse)
   ;;  Return t if mouse pointer and point cursor are too close.
-  ;; Acceptable distance is defined by mouse-avoidance-threshhold.
+  ;; Acceptable distance is defined by mouse-avoidance-threshold.
   (let ((point (mouse-avoidance-point-position)))
     (and (eq (car mouse) (car point))